@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 974 2008-09-03 04:16:18Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 1182 2008-11-07 04:25:44Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -903,6 +903,19 @@ class BaseWidgetContainer
 			return count($this->guidanceMessage);
 		}
 	}
+	/**
+	 * メッセージが存在するかを返す
+	 *
+	 * @return 				true=メッセージが存在、false=メッセージなし
+	 */
+	function isExistsMsg()
+	{
+		if (count($this->errorMessage) + count($this->warningMessage) + count($this->guidanceMessage) > 0){
+			return true;
+		} else {
+			return false;
+		}
+	}
 	/**
 	 * パスワード生成
 	 *
