@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemDb.php 1061 2008-10-07 08:20:28Z fishbone $
+ * @version    SVN: $Id: systemDb.php 1181 2008-11-07 04:05:22Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/baseDb.php');
@@ -21,6 +21,8 @@ class SystemDb extends BaseDb
 	const MAX_ACCESS_LOG_REQUEST_LENGTH = 500;				// リクエストの最大長
 	const ADMIN_KEY_LIFETIME = 1440;							// 管理者一時キーの生存期間(分)
 	const INDEX_ADD_VALUE = 5;								// 表示順の増加分
+	const CONFIG_KEY_DEFAULT_TEMPLATE			= 'default_template';			// システム定義値取得用キー(PC用デフォルトテンプレート)
+	const CONFIG_KEY_DEFAULT_TEMPLATE_MOBILE	= 'mobile_default_template';	// システム定義値取得用キー(携帯用デフォルトテンプレート)
 	
 	/**
 	 * システム定義値を取得
@@ -328,14 +330,7 @@ class SystemDb extends BaseDb
 	 */
 	function getDefaultTemplateId()
 	{
-		$retValue = '';
-		$queryStr = 'SELECT tm_id FROM _templates ';
-		$queryStr .=  'WHERE tm_default = true ';
-		$queryStr .=  'AND tm_mobile = false ';		// 携帯用でない
-		$queryStr .=  'AND tm_deleted = false';
-		$ret = $this->selectRecord($queryStr, array(), $row);
-		if ($ret) $retValue = $row['tm_id'];
-		return $retValue;
+		return $this->getSystemConfig(self::CONFIG_KEY_DEFAULT_TEMPLATE);// システム定義値取得用キー(PC用デフォルトテンプレート)
 	}
 	/**
 	 * 携帯用デフォルトのテンプレートIDを取得
@@ -344,14 +339,7 @@ class SystemDb extends BaseDb
 	 */
 	function getDefaultMobileTemplateId()
 	{
-		$retValue = '';
-		$queryStr = 'SELECT tm_id FROM _templates ';
-		$queryStr .=  'WHERE tm_default = true ';
-		$queryStr .=  'AND tm_mobile = true ';		// 携帯用
-		$queryStr .=  'AND tm_deleted = false';
-		$ret = $this->selectRecord($queryStr, array(), $row);
-		if ($ret) $retValue = $row['tm_id'];
-		return $retValue;
+		return $this->getSystemConfig(self::CONFIG_KEY_DEFAULT_TEMPLATE_MOBILE);// システム定義値取得用キー(携帯用デフォルトテンプレート)
 	}
 	/**
 	 * テンプレート情報の取得
@@ -452,6 +440,27 @@ class SystemDb extends BaseDb
 		$retValue = $this->selectRecords($queryStr, array($pageId, $widgetId, $setId), $rows);
 		return $retValue;
 	}
+	/**
+	 * 指定したコンテンツが表示可能なサブページIDを取得
+	 *
+	 * @param string $contentType	ウィジェットID
+	 * @param string $pageId		ページID
+	 * @return string				サブページID、該当なしのときは空
+	 */
+	function getSubPageIdWithContent($contentType, $pageId)
+	{
+		$retValue = '';
+		$pageParam = '';		// パラメータなしのページ
+		$queryStr = 'SELECT * FROM _page_info ';
+		$queryStr .=  'WHERE pn_deleted = false ';// 削除されていない
+		$queryStr .=  'AND pn_id = ? ';
+		$queryStr .=  'AND pn_param = ? ';
+		$queryStr .=  'AND pn_content_type = ? ';
+		$queryStr .=  'ORDER BY pn_sub_id';
+		$ret = $this->selectRecord($queryStr, array($pageId, $pageParam, $contentType), $row);
+		if ($ret) $retValue = $row['pn_sub_id'];
+		return $retValue;
+	}
 	/**
 	 * ウィジェットタイプからウィジェットIDを取得
 	 *
