@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pageManager.php 1167 2008-11-03 10:53:43Z fishbone $
+ * @version    SVN: $Id: pageManager.php 1187 2008-11-07 09:54:10Z fishbone $
  * @link       http://www.magic3.org
  */
 class PageManager
@@ -49,6 +49,7 @@ class PageManager
 	private $libFiles;					// javascript追加用ライブラリ
 	private $pageDefRev = 234;				// 画面定義のリビジョン番号
 	const ADMIN_WIDGET_ID = 'admin_main';		// 管理用ウィジェットのウィジェットID
+	const CONTENT_TYPE_WIKI = 'wiki';		// ページのコンテンツタイプ(Wiki)
 	const WIDGET_ID_TAG_START = '{{WIDGETID:';		// 遅延実行用タグ
 	const WIDGET_ID_TAG_END = '}}';		// 遅延実行用タグ
 	const WIDGET_ID_SEPARATOR = ',';
@@ -99,7 +100,6 @@ class PageManager
 	const JQUERY_CLUETIP_CSS		= 'jquery/jquery.cluetip.css';
 	
 	// ファイル名
-	const MOOTOOLS_FILENAME			= 'mootools-release-1.11.js';			// mootools
 	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';						// JQuery
 	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.5.2.packed.js';				// JQuery UI Core (core+Interaction)
 	const JQUERY_UI_PLUS_FILENAME	= 'jquery-ui-plus-1.5.2.packed.js';				// JQuery UI Core (widgets+effects)
@@ -114,7 +114,8 @@ class PageManager
 	const M3_ADMIN_WIDGET_SCRIPT_FILENAME	= 'm3admin_widget1.3.0.js';	// 管理機能(ウィジェット操作)用スクリプト
 	const M3_ADMIN_WIDGET_CSS_FILE			= '/m3/widget.css';			// 管理機能(ウィジェット操作)用CSSファイル
 	const M3_STD_SCRIPT_FILENAME			= 'm3std1.3.1.js';
-	const M3_AJAX_SCRIPT_FILENAME			= 'm3ajax1.1.js';
+	//const M3_AJAX_SCRIPT_FILENAME			= 'm3ajax1.1.js';
+	const M3_OPTION_SCRIPT_FILENAME			= 'm3opt1.0.0.js';		// AJAXを含んだオプションライブラリファイル(jQurry必須)
 	
 	/**
 	 * コンストラクタ
@@ -141,7 +142,8 @@ class PageManager
 											//self::FCKEDITOR_FILENAME,			// FCKEditor
 											self::M3_STD_SCRIPT_FILENAME,
 											self::M3_ADMIN_SCRIPT_FILENAME,
-											self::M3_AJAX_SCRIPT_FILENAME);
+											self::M3_OPTION_SCRIPT_FILENAME);
+											//self::M3_AJAX_SCRIPT_FILENAME);
 		$this->defaultAdminCssFiles = array();
 		
 		// Javascriptライブラリ
@@ -376,12 +378,23 @@ class PageManager
 				session_regenerate_id(true);
 			}
 		}
-		// URLパラメータからコンテンツ形式を取得し、ページを選択
 		
-		// ページサブIDを取得
-		$subId = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_SUB_ID);
-		if (empty($subId)) $subId = $gEnvManager->getDefaultPageSubId();
-		$gEnvManager->setCurrentPageSubId($subId);
+		// ##### サブページIDの設定 #####
+		$subId = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_SUB_ID);// ページサブIDを取得
+		if (empty($subId)){			// サブページIDが設定されていないとき
+			// URLパラメータからコンテンツ形式を取得し、ページを選択
+			// 「http://www.example.com?ページ名」「wcmd」の場合はwikiコンテンツページを選択
+			$wikiCmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_WIKI_COMMAND);
+			$pageName = $gRequestManager->getWikiPageFromQuery();
+			
+			if (!empty($wikiCmd) || !empty($pageName)){			// Wikiコンテンツページを指定のとき
+				// ページサブIDを取得
+				$subId = $this->db->getSubPageIdWithContent(self::CONTENT_TYPE_WIKI, $gEnvManager->getCurrentPageId());
+			}
+			
+			if (empty($subId)) $subId = $gEnvManager->getDefaultPageSubId();
+		}
+		$gEnvManager->setCurrentPageSubId($subId);// サブページIDを設定
 		
 		// セッションからユーザ情報を取得
 		$userInfo = $gRequestManager->getSessionValueWithSerialize(M3_SESSION_USER_INFO);
@@ -1119,7 +1132,8 @@ class PageManager
 			// Ajaxライブラリを使用しているウィジェットがあるときは追加
 			if ($this->db->isExistsWidgetWithAjax($gEnvManager->getCurrentPageId(), $gEnvManager->getCurrentPageSubId())){
 				$this->addScriptFile(self::JQUERY_FILENAME);		// デフォルトAjaxライブラリ追加
-				$this->addScriptFile(self::M3_AJAX_SCRIPT_FILENAME);	// Magic3のAjaxライブラリ追加
+				$this->addScriptFile(self::M3_OPTION_SCRIPT_FILENAME);	// Magic3のオプションライブラリ追加
+				//$this->addScriptFile(self::M3_AJAX_SCRIPT_FILENAME);	// Magic3のAjaxライブラリ追加
 			}
 				
 			$count = count($this->defaultScriptFiles);
@@ -1806,7 +1820,7 @@ class PageManager
 		$toUrl = $url;
 		if (empty($toUrl)){
 			$toUrl = $gEnvManager->getCurrentScriptUrl();
-		} else if (strncmp($toUrl, 'http://', 7) != 0){
+		} else if (strncmp($toUrl, 'http://', 7) != 0 && strncmp($toUrl, 'https://', 8) != 0){	// URL以外のときはクエリー文字列と判断する
 			$toUrl = $gEnvManager->getCurrentScriptUrl() . $toUrl;
 		}
 		
