@@ -309,7 +309,6 @@ CREATE TABLE _templates (
     tm_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレート名
     tm_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
     tm_url               TEXT                                         NOT NULL,      -- 取得先URL
-    tm_default           BOOLEAN        DEFAULT false                 NOT NULL,      -- デフォルトフラグ
     tm_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか
     tm_available         BOOLEAN        DEFAULT true                  NOT NULL,      -- メニューから選択可能かどうか
     
@@ -450,8 +449,10 @@ DROP TABLE IF EXISTS _page_id;
 CREATE TABLE _page_id (
     pg_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- ページメインID、ページサブID
     pg_type              INT            DEFAULT 0                     NOT NULL,      -- ページID種別(0=ページメインID,1=ページサブID)
+    
     pg_default_sub_id    VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- デフォルトのサブページID(ページID種別がページメインIDとき使用)
     pg_path              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセスポイントパス(ページID種別がページメインIDとき使用)
+    pg_class             VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 起動クラス名(ページID種別がページメインIDとき使用)
     pg_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ページ名称
     pg_description       VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 説明
     pg_priority          INT            DEFAULT 0                     NOT NULL,      -- 優先度
@@ -468,7 +469,6 @@ CREATE TABLE _page_info (
     pn_id                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ページID
     pn_sub_id            VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ページ補助ID
     pn_param             VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- その他のURLパラメータ
-    pn_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
     pn_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
 
     pn_template_id       VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレートID
@@ -487,7 +487,7 @@ CREATE TABLE _page_info (
     pn_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
     pn_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
     PRIMARY KEY          (pn_serial),
-    UNIQUE               (pn_id,        pn_sub_id,   pn_param,        pn_language_id,  pn_history_index)
+    UNIQUE               (pn_id,        pn_sub_id,   pn_param,        pn_history_index)
 ) TYPE=innodb;
 
 -- ページ定義マスター
