@@ -5,32 +5,35 @@
 
 -- システム設定マスター
 -- システムの動作に影響する設定を管理する
-INSERT INTO _system_config (sc_id,                         sc_value, sc_name,                sc_index) VALUES
-('system_name',                 'Magic3',     'システム名称',                      0),
-('db_version',                  '2008110301', 'DBバージョン',                      1),
-('server_id',                   '',           'サーバ識別用ID',                    2),
-('default_lang',                'ja',         'デフォルト言語',                    3),
-('multi_language',               '0',          '多言語対応',                       4),
-('csv_upload_encoding',         'SJIS-win',   'CSVアップロードエンコード',         5),
-('csv_download_encoding',       'SJIS-win',   'CSVダウンロードエンコード',         6),
-('csv_delim_code',              ',',          'CSV区切りコード',                   7),
-('csv_nl_code',                 '\r\n',       'CSV改行コード',                     8),
-('csv_file_suffix',             '.csv',       'CSVファイル拡張子',                 9),
-('permit_init_system',          '0',          'システム初期化許可',                10),
-('permit_change_lang',          '1',          '処理言語変更許可',                  11),
-('permit_detail_config',        '0',          'システム詳細設定許可',              12),
-('regenerate_session_id',       '0',          'セッションID毎回更新',              13),
-('script_cache_in_browser',     '1',          'ブラウザのスクリプトキャッシュ',    14),
-('site_in_public',              '1',          'サイト公開',                        15),
-('site_m_in_public',            '1',          '携帯サイト公開',                    16),
-('site_access_exception_ip',    '',           'サイトアクセス制御なしIP',          17),
-('toppage_image_path',          '',           'トップページ画像パス',              18),
-('mobile_encoding',             'SJIS',       '携帯用画面エンコード',              19),
-('install_dt',                  '',           'インストール日時',                  20),
-('log_dir',                     '',           'ログ出力ディレクトリ',              21),
-('work_dir',                    '',           '作業用ディレクトリ',                22),
-('default_template',            '',           '一般画面用デフォルトテンプレート',  23),
-('admin_default_template',      '_admin',     '管理画面用デフォルトテンプレート',  24);
+INSERT INTO _system_config 
+(sc_id,                          sc_value,                  sc_name,                              sc_index) VALUES
+('system_name',                 'Magic3',                   'システム名称',                       0),
+('db_version',                  '2008110601',               'DBバージョン',                       1),
+('server_id',                   '',                         'サーバ識別用ID',                     2),
+('default_lang',                'ja',                       'デフォルト言語',                     3),
+('multi_language',               '0',                       '多言語対応',                         4),
+('csv_upload_encoding',         'SJIS-win',                 'CSVアップロードエンコード',          5),
+('csv_download_encoding',       'SJIS-win',                 'CSVダウンロードエンコード',          6),
+('csv_delim_code',              ',',                        'CSV区切りコード',                    7),
+('csv_nl_code',                 '\r\n',                     'CSV改行コード',                      8),
+('csv_file_suffix',             '.csv',                     'CSVファイル拡張子',                  9),
+('permit_init_system',          '0',                        'システム初期化許可',                 10),
+('permit_change_lang',          '1',                        '処理言語変更許可',                   11),
+('permit_detail_config',        '0',                        'システム詳細設定許可',               12),
+('regenerate_session_id',       '0',                        'セッションID毎回更新',               13),
+('script_cache_in_browser',     '1',                        'ブラウザのスクリプトキャッシュ',     14),
+('site_in_public',              '1',                        'サイト公開',                         15),
+('site_m_in_public',            '1',                        '携帯サイト公開',                     16),
+('site_access_exception_ip',    '',                         'サイトアクセス制御なしIP',           17),
+('toppage_image_path',          '',                         '管理画面トップページ画像パス',       18),
+('mobile_encoding',             'SJIS',                     '携帯用画面エンコード',               19),
+('install_dt',                  '',                         'インストール日時',                   20),
+('log_dir',                     '',                         'ログ出力ディレクトリ',               21),
+('work_dir',                    '',                         '作業用ディレクトリ',                 22),
+('default_template',            'carnival',                 'PC一般画面用デフォルトテンプレート', 23),
+('admin_default_template',      '_admin',                   '管理画面用デフォルトテンプレート',   24),
+('mobile_default_template',     'm/default',                '携帯画面用デフォルトテンプレート',   25),
+('head_title_format',           '$1;$1 - $2;$1 - $2 - $3;', 'HTMLヘッダタイトルフォーマット',     26);
 
 -- 多言語対応文字列マスター
 INSERT INTO _language_string
