@@ -331,52 +331,52 @@ INSERT INTO _widgets
 
 -- テンプレート情報
 TRUNCATE TABLE _templates;
-INSERT INTO _templates (tm_id,         tm_name,      tm_description, tm_default, tm_create_dt) 
-VALUES                 ('a6greyflash', 'a6greyflash','',             false,      now());
-INSERT INTO _templates (tm_id,         tm_name,      tm_description, tm_default, tm_create_dt) 
-VALUES                 ('baki',        'baki',       '',             false,     now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('jt_millennium_expresso', 'jt_millennium_expresso', '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('jt_simplicity_red',      'jt_simplicity_red',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('baladibol',              'baladibol',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('eastertime-1.0',         'eastertime-1.0',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('ellipse',                'ellipse',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('freshgreen',             'freshgreen',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('psychic',                'psychic',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('rd_music',               'rd_music',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('siteground44',           'siteground44',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('browns',                 'browns',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('red_rose_beauty',        'red_rose_beauty',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('ec_simple_n2',           'ec_simple_n2',           '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('ec_simple_n2_pink',      'ec_simple_n2_pink',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('ec_simple_n3',           'ec_simple_n3',           '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('ec_simple_n3_aqua',      'ec_simple_n3_aqua',      '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('ec_simple_w2',           'ec_simple_w2',           '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('ec_simple_w3',           'ec_simple_w3',           '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('simple_green1',          'simple_green1',           '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('carnival',               'carnival',               '',             true,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('what',                   'what',                   '',             false,      now());
-INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_mobile, tm_create_dt) 
-VALUES                 ('m/default',             'm/default',               '',             true,       true,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('a6greyflash',            'a6greyflash',            '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('baki',                   'baki',                   '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('jt_millennium_expresso', 'jt_millennium_expresso', '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('jt_simplicity_red',      'jt_simplicity_red',      '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('baladibol',              'baladibol',              '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('eastertime-1.0',         'eastertime-1.0',         '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('ellipse',                'ellipse',                '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('freshgreen',             'freshgreen',             '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('psychic',                'psychic',                '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('rd_music',               'rd_music',               '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('siteground44',           'siteground44',           '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('browns',                 'browns',                 '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('red_rose_beauty',        'red_rose_beauty',        '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('ec_simple_n2',           'ec_simple_n2',           '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('ec_simple_n2_pink',      'ec_simple_n2_pink',      '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('ec_simple_n3',           'ec_simple_n3',           '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('ec_simple_n3_aqua',      'ec_simple_n3_aqua',      '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('ec_simple_w2',           'ec_simple_w2',           '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('ec_simple_w3',           'ec_simple_w3',           '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('simple_green1',          'simple_green1',          '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('carnival',               'carnival',               '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_create_dt) 
+VALUES                 ('what',                   'what',                   '',             now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_mobile, tm_create_dt) 
+VALUES                 ('m/default',             'm/default',               '',             true,      now());
 
 -- 基本テーブルの不要なデータを削除
 -- 画面定義
