@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 1168 2008-11-04 06:44:15Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 1184 2008-11-07 05:01:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -21,6 +21,8 @@ class admin_mainDb extends BaseDb
 	private $now;		// 現在日時
 	private $userId;		// ログイン中のユーザ
 	private $maxNo;		// 最大管理番号
+	const CONFIG_KEY_DEFAULT_TEMPLATE			= 'default_template';			// システム定義値取得用キー(PC用デフォルトテンプレート)
+	const CONFIG_KEY_DEFAULT_TEMPLATE_MOBILE	= 'mobile_default_template';	// システム定義値取得用キー(携帯用デフォルトテンプレート)
 	
 	// 取得値
 	const CAN_DETAIL_CONFIG = 'permit_detail_config';				// 詳細設定が可能かどうか
@@ -1249,7 +1251,6 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   'tm_id, ';
 		$queryStr .=   'tm_history_index, ';
 		$queryStr .=   'tm_name, ';
-		$queryStr .=   'tm_default, ';
 		$queryStr .=   'tm_create_user_id, ';
 		$queryStr .=   'tm_create_dt ';
 		$queryStr .= ') VALUES (';
@@ -1257,9 +1258,8 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
-		$queryStr .=   '?, ';
 		$queryStr .=   '?)';
-		$this->execStatement($queryStr, array($row['tm_id'], $historyIndex, $name, intval($row['tm_default']), $userId, $now));
+		$this->execStatement($queryStr, array($row['tm_id'], $historyIndex, $name, $userId, $now));
 
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -1310,58 +1310,7 @@ class admin_mainDb extends BaseDb
 	 */
 	function changeDefaultTemplate($templateId)
 	{
-		global $gEnvManager;
-		
-		$now = date("Y/m/d H:i:s");	// 現在日時
-		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
-				
-		// トランザクション開始
-		$this->startTransaction();
-		
-		// PC用のテンプレートを取得
-		if (!$this->getAllTemplateIdList($rows)){
-			// トランザクション確定
-			$ret = $this->endTransaction();
-			return false;
-		}
-
-		for ($i = 0; $i < count($rows); $i++){
-			$isDefault = 0;
-			if ($rows[$i]['tm_id'] == $templateId) $isDefault = 1;
-			$serial = $rows[$i]['tm_serial'];
-			$historyIndex = $rows[$i]['tm_history_index'] + 1;
-
-			// 古いレコードを削除
-			$queryStr  = 'UPDATE _templates ';
-			$queryStr .=   'SET tm_deleted = true, ';	// 削除
-			$queryStr .=     'tm_update_user_id = ?, ';
-			$queryStr .=     'tm_update_dt = ? ';
-			$queryStr .=   'WHERE tm_serial = ?';
-			$this->execStatement($queryStr, array($userId, $now, $serial));
-
-			// 新規レコード追加
-			$queryStr  = 'INSERT INTO _templates (';
-			$queryStr .=   'tm_id, ';
-			$queryStr .=   'tm_history_index, ';
-			$queryStr .=   'tm_name, ';
-			$queryStr .=   'tm_default, ';
-			$queryStr .=   'tm_mobile, ';
-			$queryStr .=   'tm_create_user_id, ';
-			$queryStr .=   'tm_create_dt ';
-			$queryStr .= ') VALUES (';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?)';
-			$this->execStatement($queryStr, array($rows[$i]['tm_id'], $historyIndex, $rows[$i]['tm_name'], $isDefault, (int)$rows[$i]['tm_mobile'], $userId, $now));
-		}
-		
-		// トランザクション確定
-		$ret = $this->endTransaction();
-		return $ret;
+		return $this->updateSystemConfig(self::CONFIG_KEY_DEFAULT_TEMPLATE, $templateId);
 	}
 	/**
 	 * 携帯用デフォルトテンプレートの変更
@@ -1371,71 +1320,7 @@ class admin_mainDb extends BaseDb
 	 */
 	function changeDefaultMobileTemplate($templateId)
 	{
-		global $gEnvManager;
-		
-		$now = date("Y/m/d H:i:s");	// 現在日時
-		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
-				
-		// トランザクション開始
-		$this->startTransaction();
-		
-		// 携帯用のテンプレートを取得
-		if (!$this->getAllMobileTemplateIdList($rows)){
-			// トランザクション確定
-			$ret = $this->endTransaction();
-			return false;
-		}
-		
-		for ($i = 0; $i < count($rows); $i++){
-			$isDefault = 0;
-			if ($rows[$i]['tm_id'] == $templateId) $isDefault = 1;
-			$serial = $rows[$i]['tm_serial'];
-			$historyIndex = $rows[$i]['tm_history_index'] + 1;
-			
-			// 古いレコードを削除
-			$queryStr  = 'UPDATE _templates ';
-			$queryStr .=   'SET tm_deleted = true, ';	// 削除
-			$queryStr .=     'tm_update_user_id = ?, ';
-			$queryStr .=     'tm_update_dt = ? ';
-			$queryStr .=   'WHERE tm_serial = ?';
-			$this->execStatement($queryStr, array($userId, $now, $serial));
-
-			// 新規レコード追加
-			$queryStr  = 'INSERT INTO _templates (';
-			$queryStr .=   'tm_id, ';
-			$queryStr .=   'tm_history_index, ';
-			$queryStr .=   'tm_name, ';
-			$queryStr .=   'tm_default, ';
-			$queryStr .=   'tm_mobile, ';
-			$queryStr .=   'tm_create_user_id, ';
-			$queryStr .=   'tm_create_dt ';
-			$queryStr .= ') VALUES (';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?, ';
-			$queryStr .=   '?)';
-			$this->execStatement($queryStr, array($rows[$i]['tm_id'], $historyIndex, $rows[$i]['tm_name'], $isDefault, (int)$rows[$i]['tm_mobile'], $userId, $now));
-		}
-		
-		// トランザクション確定
-		$ret = $this->endTransaction();
-		return $ret;
-	}
-	/**
-	 * テンプレートの取得
-	 *
-	 * @param string  $serial		シリアル番号
-	 * @return						true=正常、false=異常
-	 */
-	function getTemplate($serial, &$row)
-	{
-		$queryStr  = 'select * from _templates ';
-		$queryStr .=   'where tm_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
-		return $ret;
+		return $this->updateSystemConfig(self::CONFIG_KEY_DEFAULT_TEMPLATE_MOBILE, $templateId);
 	}
 	/**
 	 * 通貨一覧を取得
